%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%
%% Subversion file information - please do not edit this block
%% $Rev: 882 $
%% $Date: 2011-01-10 09:06:33 +0100 (Mon, 10 Jan 2011) $
%% $Author: nash $
%% $Id: aggregateLatereg.Rd 882 2011-01-10 08:06:33Z nash $
%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

\name{aggregateLatereg}
\alias{aggregateLatereg}
\alias{reintegrate.indb}
\title{
  Aggregate late-registered births to year of occurrence and reintegrate them with
  other births
}
\description{
  \code{aggregateLatereg} combines overlapping Lexis triangles of late-registered birth
  to a single record for the year of occurence. \code{reintegrate.indb} attempts to
  combine Lexis shapes containing late-registered births with identical Lexis shapes containing
  normally-registered births.
}
\usage{
aggregateLatereg(indb)
reintegrate.indb(indb, indbL)
}
\arguments{
  \item{indb}{
  A data frame, for \code{aggregateLatereg}, containing only late-registered births by Lexis
  triangles, and for \code{reintegrate.indb}, containing a standardised input DB.
}
  \item{indbL}{
  A data frame containing an inputDB internal representation of only late-registered births.
}
}
\details{
  For \code{reintegrate.indb}, any late-registered births which are not recorded in a Lexis shape
  which is in \code{indb} will not be integrated but will be separately recorded in the result.
  This may be the case where \code{indb} has not been split and standardised. Such records
  may be identified where \verb{Year != YearReg}.
}
\value{
  A modified \code{indb} with, for \code{aggregateLatereg}, the births aggregated to Lexis
  triangles in year of occurrence, and for \code{reintegrate.indb}, the late-registered
  births aggregated to existing shapes in the year of occurence.
}
\author{
  Edward Nash \email{nash@demogr.mpg.de}
}
\seealso{
  \code{\link{splitVH}} for splitting births by Lexis VH to triangles
}
\examples{
\dontrun{
# requires FINbirths.txt from HFD
dta <- indb.standard("FINbirths.txt")
dtaL <- subset(dta, Year != YearReg)
dta <- subset(dta, Year == YearReg)
dtaL <- aggregateLatereg(dtaL)
dtaL <- splitVH(dtaL)
dta <- reintegrate.indb(dta, dtaL)
}
}
