%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%
%% Subversion file information - please do not edit this block
%% $Rev: 882 $
%% $Date: 2011-01-10 09:06:33 +0100 (Mon, 10 Jan 2011) $
%% $Author: nash $
%% $Id: aggregateLexis.births.Rd 882 2011-01-10 08:06:33Z nash $
%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

\name{aggregateLexis.births}
\alias{aggregateLexis.births}
\alias{aggregateLexis.births1}
\alias{aggregRR.births}
\alias{aggregVV.births}
\title{
  Aggregate births by Lexis triangles to a given shape
}
\description{
  These functions allow births which are recorded by Lexis triangle to be aggregated
  to a different Lexis shape.
}
\usage{
aggregateLexis.births(dta, Lexis = "RR")
aggregateLexis.births1(dta, Lexis = "RR")
aggregRR.births(dta)
aggregVV.births(dta)
}
\arguments{
  \item{dta}{
  A data frame representing an HFD inputDB in internal format
}
  \item{Lexis}{
  The Lexis shape to aggregate to; RR or VV.
}
}
\details{
 \code{aggregRR.births} and \code{aggregVV.births} may be conveniently accessed by
 the wrapper function \code{aggregate.Lexis.births1}, and all these functions operate only on a
 single year of data (i.e. \code{dta} must contain births for only one Year).
 \code{aggregateLexis.births} may be used with \code{dta} containing births for many years: in
 this case, the births are split by year before being passed to \code{aggregateLexis.births1}.
}
\value{
  A modified version of \code{dta} with births aggregated to the chosen shape
}
\references{
  Jasilioniene et al.: Methods Protocol for the Human Fertility Database.
  Available from \url{http://www.humanfertility.org} 
}
\author{
Dmitri Jdanov \email{jdanov@demogr.mpg.de}
}
\seealso{
  \code{\link{exps.aggregate.age}} and \code{\link{scaleBirths}} for other forms of
  aggregation.
}
\examples{
\dontrun{
# requires FINbirths.txt from the HFD
dta <- indb.standard("FINbirths.txt")
dta <- subset(dta, Year == 2008)
dta <- aggregateLexis.births(dta, "RR")
}
}
