%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%
%% Subversion file information - please do not edit this block
%% $Rev: 882 $
%% $Date: 2011-01-10 09:06:33 +0100 (Mon, 10 Jan 2011) $
%% $Author: nash $
%% $Id: indb.standard.Rd 882 2011-01-10 08:06:33Z nash $
%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

\name{indb.standard}
\alias{indb.standard}
\alias{missing.ages}
\title{
  Standardise the age- and order range in a HFD inputDB
}
\description{
  \code{indb.standard} standardises the age (10-60) and birth order (1-5+) range in a HFD input
  database as a prelude to further processing.
  
  \code{missing.ages} produces a data frame containing records corresponding to missing ages
  in a HFD input database.
}
\usage{
indb.standard(indb = NA, fname = "", minA = 10, maxA = 60, maxO = 5, print = FALSE)
missing.ages(dta, minA = 10, maxA = 60)
}
\arguments{
  \item{indb}{
  A data frame representing an HFD input DB in internal format
}
  \item{fname}{
  The filename from which to read an HFD input DB
}
  \item{dta}{
  A data frame representing an HFD input DB in internal format for a single year and birth order
}
  \item{minA}{
  The minimum age down to which the age range must be complete  
}
  \item{maxA}{
  The maximum age up to which the age range must be complete
}
  \item{maxO}{
  The highest (open) birth order to retain.
}
  \item{print}{
  Boolean indicating whether to deserialise the standardised database to file (XXXbirths.txt
  in the working directory).
}
}
\details{
  Only one of \code{indb} and \code{fname} should be supplied: \code{indb} has priority.
}
\value{
  For \code{indb.standard}, a modified \code{indb} with age and birth-order range standardised.
  
  For \code{missing.ages}, a data frame in HFD inputDB format containing records for ages missing
  from \code{indb}.
}
\references{
  Jasilioniene et al.: Methods Protocol for the Human Fertility Database.
  Available from \url{http://www.humanfertility.org} 
}
\author{
  Dmitri Jdanov \email{jdanov@demogr.mpg.de}
}
\seealso{
  \code{\link{indbLoad}} for reading a HFD input file into internal format.
}
\examples{
\dontrun{
# requires USAbirths.txt from HFD
dta <- indb.standard(fname = "USAbirths.txt")
}
}
