%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%
%% Subversion file information - please do not edit this block
%% $Rev: 882 $
%% $Date: 2011-01-10 09:06:33 +0100 (Mon, 10 Jan 2011) $
%% $Author: nash $
%% $Id: split.births.Rd 882 2011-01-10 08:06:33Z nash $
%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

\name{split.births}
\alias{split1.births}
\alias{split1}
\alias{split5.births}
\alias{split5.births.phantom}
\alias{split5}
\alias{adjust}
\title{
  Split births into single ages or triangles using spline interpolation
}
\description{
  \code{split1.births} and \code{split5.births} may be used to split birth data
  recorded in 1-year age intervals into triangles and in 5-year or open-ended age
  intervals into 1-year age intervals respectively.
  
  \code{split5.births.phantom} is an alternative to \code{split5.births}, performing
  exactly the same function but substituting 0s in the lowest (open) age category
  with 1 before splitting, and removing the substitution afterwards.
  
  The other functions described
  here are used internally and are generally not called directly.
}
\usage{
split1.births(dta, exps, verbose = TRUE)
split5.births(dta, exps, Lexis = "RR", verbose = TRUE)
split5.births.phantom(dta, exps, Lexis = "RR", verbose = TRUE)
split1(births, exps, monthly = vector(mode = "numeric", 12) + 1, delta = 1e-04)
split5(births, exps)
adjust(dta1, dta2)
}
\arguments{
  \item{dta}{
  A data frame representing a HFD input file in internal format. It is assumed
  that unknowns have already been distributed appropriately.
}
  \item{exps}{
  A data frame representing a HFD LexisDB file of female population exposures.
}
  \item{verbose}{
  Boolean indicating whether progress information should be printed to the console/stdout.
}
  \item{births}{
  As for \code{dta}, but for a single year and birth order.
}
  \item{monthly}{
  Length 12 vector of relative birth distribution by month in the year.
}
  \item{delta}{
  Size of interval to use for integration.
}
  \item{Lexis}{
  Target shape for splitting into 1-year age groups.
}
  \item{dta1}{
  Data frame containing split data.
}
  \item{dta2}{
  Data frame containing original, unsplitted data to which the appropriate sums in \code{dta1}
  should be adjusted.
}
}
\details{
  \code{split1} and \code{split5} both use a piece-wise cubic Hermite polynomial spline
  to interpolate a Logit transformation of the cumulative fertility rate in order to split
  births, as described in the HFD Methods Protocol. \code{split1.births} and \code{split5.births}
  provide convenient wrappers to separate the data by year and birth order and to perform
  iterative proportional fitting on the split data in order to ensure correspondence of
  marginal totals.
}
\value{
  A data frame with the split (or adjusted) births data.
}
\references{
  Jasilioniene et al.: Methods Protocol for the Human Fertility Database.
  Available from \url{http://www.humanfertility.org} 
}
\author{
  Dmitri Jdanov \email{jdanov@demogr.mpg.de} with minor modifications
  by Edward Nash \email{nash@demogr.mpg.de}
}
\seealso{
  \code{link{split.vh}} and \code{\link{splitRR2TLTU.births}} for other special-purpose
  splitting.
}
\examples{
\dontrun{
# requires RUSbirths.txt and RUSmonthly.txt from HFD and fRUS.txt from HMD
dta <- indb.standard("RUSbirths.txt")
dta <- unk.unk(dta)
dta <- unk.bo(dta)
dta <- unk.age(dta)
dta <- unk.IPF(dta)
exps <- indbExposure("fRUS.txt", "RUSmonthly.txt", outfile = NA)
dta <- split5.births(dta, exps)
dta <- split1.births(dta, exps)
}
}
